pkgdown/in_header.html

Skip to contents

Ready-to-use CGF for a univariate Normal distribution with parameters \((\mu,\sigma)\).

Usage

NormalCGF

GaussianCGF

Format

An object of class VectorizedFunctionsCGF (inherits from CGF, R6) of length 25.

An object of class VectorizedFunctionsCGF (inherits from CGF, R6) of length 25.

Details

The parameter vector is interpreted as c(mu, sigma) (length 2), or in vectorised form as c(mu[1:L], sigma[1:L]).

With iidReps="any" (the default), length(tvec) must be a multiple of the number of parameter rows (L). In the scalar case (L=1), any length tvec is treated as i.i.d. replicates.