saddlepoint: A framework for the saddlepoint approximation with CGF operations
Source:R/saddlepoint-package.R
saddlepoint-package.RdTools for saddlepoint approximations built around composable cumulant generating function (CGF) objects. Provides CGFs for common distributions, operators to combine CGFs (i.i.d. replication, sums, linear maps, random sums and tilts), and routines for saddlepoint likelihood inference including maximum likelihood estimation. Uses RTMB for automatic differentiation where derivatives are required.
Package development
The package is still in development and there may still be bugs and errors. While we do not expect major changes to the general user interface, there may be changes to the internal workings of the package as well as new additions and functionality.