Builds a CGF for \(Y \sim N(\mu(\theta), \sigma(\theta))\), where mu and
sigma are functions (or adaptors) of theta.
Both mu(theta) and sigma(theta) may return a scalar or a vector.
If they return vectors, they must have the same length L and are interpreted
in the same vectorised way as other univariate model CGFs in this package.