Create the inequality constraint function
Source:R/B-optimization-functions.R
get.ineq.constraint.function.RdThis function wraps and returns an inequality constraint function of the form function(a) {...}, where 'a' combines tvec and theta arguments to a single vector, in that order.
Value
A function that takes a vector a as an argument. This function returns either NULL or a list with 'constraints' and 'jacobian'.
Details
This function constructs and integrates an inequality constraint based on cgf
with any user-defined inequality constraint function specified in user.ineq.constraint.function.
If user.ineq.constraint.function is NULL, the function checks whether the cgf itself
includes an inherent inequality constraint.