Create the saddlepoint equality constraint function
Source:R/B-optimization-functions.R
get.saddlepoint.eq.constraint.function.RdThis function creates and returns a function of the form function(a) {...}, where 'a' combines tvec and theta arguments to a single vector, in that order.
Value
A function that accepts a vector 'a' as an argument. When a = c(tvec, theta) is passed to this function, it generates a list containing 'constraints' and 'jacobian'. 'constraints' are computed as \(K'(t;\theta) - y\), and 'jacobian' represents the gradient of these constraints with respect to both tvec and theta.