Create the zeroth-order saddlepoint negative log-likelihood function
Source:R/B-optimization-functions.R
get.zeroth.saddlepoint.nll.function.RdThis function creates and returns a function of the form function(a) {...}, where 'a' combines tvec and theta arguments to a single vector, in that order.